<?php
/**
 * Theme functions
 *
 * @package xts
 */

use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'xts_remove_play_button_border_controls' ) ) {
	/**
	 * Add border controls.
	 *
	 * @since 1.0.0
	 */
	function xts_remove_play_button_border_controls() {
		remove_action( 'elementor/element/xts_video/style_play_button_section/before_section_end', 'xts_add_video_play_button_border_controls', 10 ); // Does not remove core filters.
	}

	add_action( 'init', 'xts_remove_play_button_border_controls', 50 );
}

if ( ! function_exists( 'xts_add_video_play_button_background_color_control' ) ) {
	/**
	 * Add play button bg color control to video element.
	 *
	 * @since 1.0.0
	 *
	 * @param object $element Element object.
	 */
	function xts_add_video_play_button_background_color_control( $element ) {
		xts_get_color_map(
			$element,
			[
				'key'              => 'play_button_icon_bg',
				'switcher_title'   => esc_html__( 'Background color', 'xts-theme' ),
				'normal_selectors' => [
					'{{WRAPPER}} div.xts-el-video .xts-el-video-play-btn' => 'background-color: {{VALUE}}',
				],
				'hover_selectors'  => [
					'{{WRAPPER}} .xts-action-play .xts-el-video-btn:hover .xts-el-video-play-btn, {{WRAPPER}} .xts-action-overlay:hover .xts-el-video-play-btn' => 'background-color: {{VALUE}}',
				],
			]
		);
	}

	add_action( 'elementor/element/xts_video/style_play_button_section/before_section_end', 'xts_add_video_play_button_background_color_control' );
}

if ( ! function_exists( 'xts_add_banner_mask_content_background_color_control' ) ) {
	/**
	 * Add bg control to banner element.
	 *
	 * @since 1.0.0
	 *
	 * @param object $element Element object.
	 */
	function xts_add_banner_mask_content_background_color_control( $element ) {
		$element->add_control(
			'mask_background',
			[
				'label'     => esc_html__( 'Background color', 'xts-theme' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .xts-iimage-content' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'banner_style' => [ 'mask-content' ],
				],
			]
		);
	}

	add_action( 'xts_banner_style_general_after_banner_style', 'xts_add_banner_mask_content_background_color_control' );
}

